@@ -108,10 +108,8 @@ again:
 
 	status = pam_authenticate(pamh, 0);
 	if (status == PAM_SUCCESS) {
-		int acct_status;
-
-		acct_status = pam_acct_mgmt(pamh, 0);
-		acct_status = pam_setcred(pamh, PAM_REINITIALIZE_CRED);
+		pam_acct_mgmt(pamh, 0);
+		pam_setcred(pamh, PAM_REINITIALIZE_CRED);
 
 	} else {
 		fprintf(stderr, "Error authenticating user.\n");
